web\_payments\_externalpayments package
=======================================

Submodules
----------

web\_payments\_externalpayments.forms module
--------------------------------------------

.. automodule:: web_payments_externalpayments.forms
    :members:
    :undoc-members:
    :show-inheritance:

web\_payments\_externalpayments.translation module
--------------------------------------------------

.. automodule:: web_payments_externalpayments.translation
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: web_payments_externalpayments
    :members:
    :undoc-members:
    :show-inheritance:
